# i3-workspace-names-daemon

This script dynamically updates [i3wm](https://i3wm.org/) workspace names based on the names of the windows therein. 

It also allows users to define an icon to show for a named window from the [Font Awesome](https://origin.fontawesome.com/icons?d=gallery) icon list.

### install

##### font 

Install the [Font Awesome](https://origin.fontawesome.com/icons?d=gallery) font via your favourite package manager. This is necessary if you want to show an icon instead of a window's name in the i3 status bar. 
 

For Debian/Ubuntu et al. 

```
sudo apt install fonts-font-awesome
```

**NB: if the glyphs are not rendering make sure the font is installed**

### config

### example config

### picking icons 

The easiest way to pick an icon is to search for one in the [gallery](https://origin.fontawesome.com/icons?d=gallery). Note: the "pro" icons are not available in the debian package as you might expect.

##### FAQ

